==> jsvg-1.2.0-sources.jar: com/github/weisj/jsvg/nodes/filter/Channel.java <==
/*
 * MIT License
 *
 * Copyright (c) 2021-2023 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.jsvg.nodes.filter;

import java.awt.*;
import java.awt.image.BufferedImage;
import java.awt.image.ImageFilter;
import java.awt.image.ImageProducer;

import org.jetbrains.annotations.NotNull;

import com.github.weisj.jsvg.renderer.RenderContext;

public interface Channel {

    @NotNull
    ImageProducer producer();

    default @NotNull Image toImage(@NotNull RenderContext context) {
        return context.createImage(producer());
    }

    default @NotNull BufferedImage toBufferedImageNonAliased(@NotNull RenderContext context) {
        return makeNonAliased(toImage(context));
    }

    static @NotNull BufferedImage makeNonAliased(@NotNull Image img) {
        BufferedImage bufferedImage = new BufferedImage(
                img.getWidth(null),
                img.getHeight(null),
                BufferedImage.TYPE_INT_ARGB);
        Graphics imageGraphics = bufferedImage.getGraphics();
        imageGraphics.drawImage(img, 0, 0, null);
        imageGraphics.dispose();
        return bufferedImage;
    }

    @NotNull
    Channel applyFilter(@NotNull ImageFilter filter);

    @NotNull
    PixelProvider pixels(@NotNull RenderContext context);
}

==> jsvg-1.4.0-sources.jar: com/github/weisj/jsvg/nodes/filter/Channel.java <==
/*
 * MIT License
 *
 * Copyright (c) 2021-2023 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.jsvg.nodes.filter;

import java.awt.*;
import java.awt.image.BufferedImage;
import java.awt.image.ImageFilter;
import java.awt.image.ImageProducer;

import org.jetbrains.annotations.NotNull;

import com.github.weisj.jsvg.renderer.RenderContext;

public interface Channel {

    @NotNull
    ImageProducer producer();

    default @NotNull Image toImage(@NotNull RenderContext context) {
        return context.platformSupport().createImage(producer());
    }

    default @NotNull BufferedImage toBufferedImageNonAliased(@NotNull RenderContext context) {
        return makeNonAliased(toImage(context));
    }

    static @NotNull BufferedImage makeNonAliased(@NotNull Image img) {
        BufferedImage bufferedImage = new BufferedImage(
                img.getWidth(null),
                img.getHeight(null),
                BufferedImage.TYPE_INT_ARGB);
        Graphics imageGraphics = bufferedImage.getGraphics();
        imageGraphics.drawImage(img, 0, 0, null);
        imageGraphics.dispose();
        return bufferedImage;
    }

    @NotNull
    Channel applyFilter(@NotNull ImageFilter filter);

    @NotNull
    PixelProvider pixels(@NotNull RenderContext context);
}
